@@ -6,7 +6,7 @@ from awxkit.api.pages import (
     Organization,
 )
 from awxkit.api.resources import resources
-from awxkit.utils import random_title, PseudoNamespace
+from awxkit.utils import random_title, PseudoNamespace, filter_by_class
 
 from . import base
 from . import page
@@ -21,22 +21,26 @@ class ExecutionEnvironment(HasCreate, HasCopy, base.Base):
     NATURAL_KEY = ('name',)
 
     # fields are name, image, organization, managed_by_tower, credential
-    def create(self, name='', image='quay.io/ansible/ansible-runner:devel', credential=None, pull='', **kwargs):
+    def create(self, name='', image='quay.io/ansible/ansible-runner:devel', organization=Organization, credential=None, pull='', **kwargs):
         # we do not want to make a credential by default
-        payload = self.create_payload(name=name, image=image, credential=credential, pull=pull, **kwargs)
+        payload = self.create_payload(name=name, image=image, organization=organization, credential=credential, pull=pull, **kwargs)
         ret = self.update_identity(ExecutionEnvironments(self.connection).post(payload))
         return ret
 
-    def create_payload(self, name='', organization=Organization, **kwargs):
-        self.create_and_update_dependencies(organization)
-        payload = self.payload(name=name, organization=self.ds.organization, **kwargs)
+    def create_payload(self, name='', organization=Organization, credential=None, **kwargs):
+        self.create_and_update_dependencies(*filter_by_class((credential, Credential), (organization, Organization)))
+
+        credential = self.ds.credential if credential else None
+        organization = self.ds.organization if organization else None
+
+        payload = self.payload(name=name, organization=organization, credential=credential, **kwargs)
         payload.ds = DSAdapter(self.__class__.__name__, self._dependency_store)
         return payload
 
     def payload(self, name='', image=None, organization=None, credential=None, pull='', **kwargs):
         payload = PseudoNamespace(
             name=name or "EE - {}".format(random_title()),
-            image=image or random_title(10),
+            image=image or "example.invalid/component:tagname",
             organization=organization.id if organization else None,
             credential=credential.id if credential else None,
             pull=pull,
